package com.srs.routine.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.srs.routine.domain.RtStuDisqualification;

import java.util.List;

/**
 * 给予学生退学申请Service接口
 *
 * @author LSD
 * @date 2024-07-31
 */
public interface IRtStuDisqualificationService extends IService<RtStuDisqualification> {
    /**
     * 查询给予学生退学申请
     *
     * @param disqualificationId 给予学生退学申请主键
     * @return 给予学生退学申请
     */
    public RtStuDisqualification selectRtStuDisqualificationByDisqualificationId(Long disqualificationId);

    /**
     * 查询给予学生退学申请列表
     *
     * @param rtStuDisqualification 给予学生退学申请
     * @return 给予学生退学申请集合
     */
    List<RtStuDisqualification> selectRtStuDisqualificationList(RtStuDisqualification rtStuDisqualification);

    /**
     * 新增给予学生退学申请
     *
     * @param rtStuDisqualification 给予学生退学申请
     * @return 结果
     */
    int insertRtStuDisqualification(RtStuDisqualification rtStuDisqualification);

    /**
     * 修改给予学生退学申请
     *
     * @param rtStuDisqualification 给予学生退学申请
     * @return 结果
     */
    int updateRtStuDisqualification(RtStuDisqualification rtStuDisqualification);

    /**
     * 批量删除给予学生退学申请
     *
     * @param disqualificationIds 需要删除的给予学生退学申请主键集合
     * @return 结果
     */
    int deleteRtStuDisqualificationByDisqualificationIds(Long[] disqualificationIds);

    /**
     * 删除给予学生退学申请信息
     *
     * @param disqualificationId 给予学生退学申请主键
     * @return 结果
     */
    int deleteRtStuDisqualificationByDisqualificationId(Long disqualificationId);

    /**
     * 修改
     * @param rtStuDisqualification
     * @return
     */
    int editRtStuDisqualification(RtStuDisqualification rtStuDisqualification);

    /**
     * 根据流程id获取数据
     * @param procInsId
     * @return
     */
    RtStuDisqualification getRtStuDisqualificationByProcInsId(String procInsId);


    List<RtStuDisqualification> selectRtStuDisqualificationListByXW(RtStuDisqualification rtStuDisqualification);
}
